@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -114,7 +114,7 @@ listener_callback (BonoboListener *l, char *event_name,
                       BonoboArg* value, CORBA_Environment *ev,
                       gpointer user_data)
 {
-	unsigned int nb;
+	gsize nb;
 	gchar* buf;
 	buf = g_strdup_printf("%s\n%s\n", event_name, BONOBO_ARG_GET_STRING(value));
 	g_io_channel_write (out_channel, buf, strlen(buf), &nb);
@@ -288,7 +288,7 @@ void setMainControl(GtkWidget *w) {
  */
 static void window_destroyed (GtkWindow *window, char * data) {
 	Bonobo_Unknown bu; 
-	unsigned int nb;
+	gsize nb;
 	
 	g_io_channel_write (out_channel, "exit\n", 5, &nb);
 	bu = bonobo_widget_get_objref (BONOBO_WIDGET(control));
@@ -480,7 +480,7 @@ static gboolean io_func(GIOChannel *source, GIOCondition condition, gpointer dat
 	}
 	
 	if (g_str_equal("exit\n", string) == TRUE) {
-		unsigned int nb;
+		gsize nb;
 		Bonobo_Unknown bu;
 		/* The command was "exit", so that's what we do */
 		
